@@ -1,6 +1,6 @@
 package Bundle::ePortal;
 
-$VERSION = 0.02;
+$VERSION = 0.03;
 
 1;
 
@@ -23,16 +23,8 @@ C<perl -MCPAN -e 'install Bundle::ePortal'>
 
 =head1 CONTENTS
 
-Apache
-
-Apache::Constants
-
-Apache::Cookie
-
 Apache::Request
 
-Apache::Util
-
 Bundle::HTML::Mason
 
 CGI
@@ -61,8 +53,6 @@ MIME::Base64
 
 MD5
 
-mod_perl
-
 Net::LDAP
 
 Params::Validate
